/**
 * @author Pascal MARTIN
 * 
 * Copyright (c) 2008 Pascal MARTIN
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

var gestionClic = function ()
{
  var myAjax = new Ajax.Request(
    './test-server.php',
    {
      method: 'get',
      parameters: {},
      onSuccess: function (xhr)
        {
          // Objet Document contenu dans la propriété responseXML
          // Et on veut lister les "personne"s présentes dans le document XML
          var nodesPersonne = xhr.responseXML.getElementsByTagName('personne');
          
          var output = '';
          for (i=0 ; i<nodesPersonne.length ; i++)
          {
            var nodePersonne = nodesPersonne[i];
            
            var attributes = nodePersonne.attributes;
            var id = attributes.getNamedItem('id').nodeValue;
            
            var nodeNom = nodePersonne.getElementsByTagName('nom')[0];
            var nom = nodeNom.firstChild.nodeValue;
            
            var nodePrenom = nodePersonne.getElementsByTagName('prenom')[0];
            var prenom = nodePrenom.firstChild.nodeValue;
            
            output += id + ' - ' 
                         + nom.toUpperCase() 
                         + ' - ' + prenom.capitalize() 
                         + '<br />';
          }
          
          
          /*
          $A(nodesPersonne).each(function (nodePersonne)
            {
              var attributes = nodePersonne.attributes;
              var id = attributes.getNamedItem('id').nodeValue;
              
              var nodeNom = nodePersonne.getElementsByTagName('nom')[0];
              var nom = nodeNom.firstChild.nodeValue;
              
              var nodePrenom = nodePersonne.getElementsByTagName('prenom')[0];
              var prenom = nodePrenom.firstChild.nodeValue;
              
              output += id + ' - ' 
                        + nom.toUpperCase() 
                        + ' - ' + prenom.capitalize() 
                        + '<br />';
            });
          */
          
          
          $('resultat').innerHTML = output;
          
        }, // onSuccess
      onFailure: function()
        {
          alert('failure');
          alert(xhr.responseText);
        }
    }
  );
};
